@@ -26,8 +26,10 @@
 # Standard library imports
 from math import copysign as copysign
 from math import degrees as degrees
+
 # Third party imports
 import ephem
+
 # Local application imports
 from pyalmanac.lib import alma_ephem as alma_ephem
 from pyalmanac.lib import config as config
@@ -205,7 +207,7 @@ def suntabm(date):
 def declCompare(prev_rad, curr_rad, next_rad, hr):
     # for Declinations only...
     # decide if to print N/S; decide if to print degrees
-    # note: the first three arguments are PyEphem angles in radians
+    # note: the first three arguments are Ephem angles in radians
     prNS = False
     prDEG = False
     psign = copysign(1.0,prev_rad)
@@ -309,7 +311,7 @@ def page(date):
         page = page + suntab(date+6)
         page = page + suntab(date+9)
         page = page + suntab(date+12)
-    # to avoid "Overfull \hbox" messages, always leave a paragraph end before the end of a size change. (See line below)
+    # to avoid "Overfull \hbox" messages, leave a paragraph end before the end of a size change. (This may only apply to tabular* table style) See lines below...
     page = page + r'''
 
 \end{scriptsize}'''
@@ -326,13 +328,15 @@ def pages(date, p):
 
 
 def almanac(first_day, pagenum, dfra):
-    # make almanac from date till date
+
+    # make almanac starting from first_day
     year = first_day.year
     mth = first_day.month
     day = first_day.day
 
     # page size specific parameters
     if config.pgsz == "A4":
+        # pay attention to the limited page width
         paper = "a4paper"
         tm = "21mm"
         bm = "18mm"
@@ -349,6 +353,7 @@ def almanac(first_day, pagenum, dfra):
             lm = "14mm"
             rm = "14mm"
     else:
+        # pay attention to the limited page height
         paper = "letterpaper"
         tm = "12.2mm"
         bm = "13mm"
@@ -400,7 +405,7 @@ def almanac(first_day, pagenum, dfra):
     alm = alm + r'''
     \vspace*{{2cm}}
     \begin{{center}}
-    \textsc{{\Large Generated by PyAlmanac}}\\[1.5cm]
+    \textsc{{\Large Generated using Ephem}}\\[1.5cm]
     \includegraphics[width=0.4\textwidth]{{{}}}\\[1cm]
     \textsc{{\huge The Nautical Almanac for the Sun}}\\[0.7cm]'''.format(dfra)
 
@@ -439,7 +444,7 @@ def almanac(first_day, pagenum, dfra):
     \end{center}
     \begin{description}\footnotesize
     \item[Disclaimer:] These are computer generated tables - use them at your own risk.
-    The accuracy has been randomly checked with JPL HORIZONS System, but cannot be guaranteed.
+    The accuracy has been checked as well as possible, but cannot be guaranteed.
     This means I cannot be held liable if you get lost on the oceans because of errors in this publication.
     Besides, this publication only contains sun tables: an official version of the Nautical Almanac is indispensable.
     \end{description}
